import * as pulumi from "@pulumi/pulumi";
/**
 * The ``AWS::ApiGatewayV2::IntegrationResponse`` resource updates an integration response for an WebSocket API. For more information, see [Set up WebSocket API Integration Responses in API Gateway](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-integration-responses.html) in the *API Gateway Developer Guide*.
 */
export declare function getIntegrationResponse(args: GetIntegrationResponseArgs, opts?: pulumi.InvokeOptions): Promise<GetIntegrationResponseResult>;
export interface GetIntegrationResponseArgs {
    /**
     * The API identifier.
     */
    apiId: string;
    /**
     * The integration ID.
     */
    integrationId: string;
    /**
     * The integration response ID.
     */
    integrationResponseId: string;
}
export interface GetIntegrationResponseResult {
    /**
     * Supported only for WebSocket APIs. Specifies how to handle response payload content type conversions. Supported values are ``CONVERT_TO_BINARY`` and ``CONVERT_TO_TEXT``, with the following behaviors:
     *   ``CONVERT_TO_BINARY``: Converts a response payload from a Base64-encoded string to the corresponding binary blob.
     *   ``CONVERT_TO_TEXT``: Converts a response payload from a binary blob to a Base64-encoded string.
     *  If this property is not defined, the response payload will be passed through from the integration response to the route response or method response without modification.
     */
    readonly contentHandlingStrategy?: string;
    /**
     * The integration response ID.
     */
    readonly integrationResponseId?: string;
    /**
     * The integration response key.
     */
    readonly integrationResponseKey?: string;
    /**
     * A key-value map specifying response parameters that are passed to the method response from the backend. The key is a method response header parameter name and the mapped value is an integration response header value, a static value enclosed within a pair of single quotes, or a JSON expression from the integration response body. The mapping key must match the pattern of ``method.response.header.{name}``, where name is a valid and unique header name. The mapped non-static value must match the pattern of ``integration.response.header.{name}`` or ``integration.response.body.{JSON-expression}``, where ``{name}`` is a valid and unique response header name and ``{JSON-expression}`` is a valid JSON expression without the ``$`` prefix.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::ApiGatewayV2::IntegrationResponse` for more information about the expected schema for this property.
     */
    readonly responseParameters?: any;
    /**
     * The collection of response templates for the integration response as a string-to-string map of key-value pairs. Response templates are represented as a key/value map, with a content-type as the key and a template as the value.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::ApiGatewayV2::IntegrationResponse` for more information about the expected schema for this property.
     */
    readonly responseTemplates?: any;
    /**
     * The template selection expression for the integration response. Supported only for WebSocket APIs.
     */
    readonly templateSelectionExpression?: string;
}
/**
 * The ``AWS::ApiGatewayV2::IntegrationResponse`` resource updates an integration response for an WebSocket API. For more information, see [Set up WebSocket API Integration Responses in API Gateway](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-integration-responses.html) in the *API Gateway Developer Guide*.
 */
export declare function getIntegrationResponseOutput(args: GetIntegrationResponseOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetIntegrationResponseResult>;
export interface GetIntegrationResponseOutputArgs {
    /**
     * The API identifier.
     */
    apiId: pulumi.Input<string>;
    /**
     * The integration ID.
     */
    integrationId: pulumi.Input<string>;
    /**
     * The integration response ID.
     */
    integrationResponseId: pulumi.Input<string>;
}
