import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Schema for AWS::ApiGatewayV2::RoutingRule
 */
export declare class RoutingRule extends pulumi.CustomResource {
    /**
     * Get an existing RoutingRule resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): RoutingRule;
    /**
     * Returns true if the given object is an instance of RoutingRule.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RoutingRule;
    readonly actions: pulumi.Output<outputs.apigatewayv2.RoutingRuleAction[]>;
    readonly conditions: pulumi.Output<outputs.apigatewayv2.RoutingRuleCondition[]>;
    /**
     * The amazon resource name (ARN) of the domain name resource.
     */
    readonly domainNameArn: pulumi.Output<string>;
    readonly priority: pulumi.Output<number>;
    /**
     * Amazon Resource Name (ARN) of the resource.
     */
    readonly routingRuleArn: pulumi.Output<string>;
    /**
     * RoutingRule Id generated by service
     */
    readonly routingRuleId: pulumi.Output<string>;
    /**
     * Create a RoutingRule resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RoutingRuleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a RoutingRule resource.
 */
export interface RoutingRuleArgs {
    actions: pulumi.Input<pulumi.Input<inputs.apigatewayv2.RoutingRuleActionArgs>[]>;
    conditions: pulumi.Input<pulumi.Input<inputs.apigatewayv2.RoutingRuleConditionArgs>[]>;
    /**
     * The amazon resource name (ARN) of the domain name resource.
     */
    domainNameArn: pulumi.Input<string>;
    priority: pulumi.Input<number>;
}
