import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::AppStream::Entitlement
 */
export declare class Entitlement extends pulumi.CustomResource {
    /**
     * Get an existing Entitlement resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Entitlement;
    /**
     * Returns true if the given object is an instance of Entitlement.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Entitlement;
    /**
     * Specifies whether to entitle all apps or only selected apps.
     */
    readonly appVisibility: pulumi.Output<string>;
    /**
     * The attributes of the entitlement.
     */
    readonly attributes: pulumi.Output<outputs.appstream.EntitlementAttribute[]>;
    /**
     * The time when the entitlement was created.
     */
    readonly createdTime: pulumi.Output<string>;
    /**
     * The description of the entitlement.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The time when the entitlement was last modified.
     */
    readonly lastModifiedTime: pulumi.Output<string>;
    /**
     * The name of the entitlement.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The name of the stack.
     */
    readonly stackName: pulumi.Output<string>;
    /**
     * Create a Entitlement resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EntitlementArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Entitlement resource.
 */
export interface EntitlementArgs {
    /**
     * Specifies whether to entitle all apps or only selected apps.
     */
    appVisibility: pulumi.Input<string>;
    /**
     * The attributes of the entitlement.
     */
    attributes: pulumi.Input<pulumi.Input<inputs.appstream.EntitlementAttributeArgs>[]>;
    /**
     * The description of the entitlement.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the entitlement.
     */
    name?: pulumi.Input<string>;
    /**
     * The name of the stack.
     */
    stackName: pulumi.Input<string>;
}
