import * as pulumi from "@pulumi/pulumi";
/**
 * The AWS::AutoScaling::ScheduledAction resource specifies an Amazon EC2 Auto Scaling scheduled action so that the Auto Scaling group can change the number of instances available for your application in response to predictable load changes.
 */
export declare function getScheduledAction(args: GetScheduledActionArgs, opts?: pulumi.InvokeOptions): Promise<GetScheduledActionResult>;
export interface GetScheduledActionArgs {
    /**
     * The name of the Auto Scaling group.
     */
    autoScalingGroupName: string;
    /**
     * Auto-generated unique identifier
     */
    scheduledActionName: string;
}
export interface GetScheduledActionResult {
    /**
     * The desired capacity is the initial capacity of the Auto Scaling group after the scheduled action runs and the capacity it attempts to maintain.
     */
    readonly desiredCapacity?: number;
    /**
     * The latest scheduled start time to return. If scheduled action names are provided, this parameter is ignored.
     */
    readonly endTime?: string;
    /**
     * The minimum size of the Auto Scaling group.
     */
    readonly maxSize?: number;
    /**
     * The minimum size of the Auto Scaling group.
     */
    readonly minSize?: number;
    /**
     * The recurring schedule for the action, in Unix cron syntax format. When StartTime and EndTime are specified with Recurrence , they form the boundaries of when the recurring action starts and stops.
     */
    readonly recurrence?: string;
    /**
     * Auto-generated unique identifier
     */
    readonly scheduledActionName?: string;
    /**
     * The earliest scheduled start time to return. If scheduled action names are provided, this parameter is ignored.
     */
    readonly startTime?: string;
    /**
     * The time zone for the cron expression.
     */
    readonly timeZone?: string;
}
/**
 * The AWS::AutoScaling::ScheduledAction resource specifies an Amazon EC2 Auto Scaling scheduled action so that the Auto Scaling group can change the number of instances available for your application in response to predictable load changes.
 */
export declare function getScheduledActionOutput(args: GetScheduledActionOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetScheduledActionResult>;
export interface GetScheduledActionOutputArgs {
    /**
     * The name of the Auto Scaling group.
     */
    autoScalingGroupName: pulumi.Input<string>;
    /**
     * Auto-generated unique identifier
     */
    scheduledActionName: pulumi.Input<string>;
}
