import * as pulumi from "@pulumi/pulumi";
/**
 * The AWS::AutoScaling::ScheduledAction resource specifies an Amazon EC2 Auto Scaling scheduled action so that the Auto Scaling group can change the number of instances available for your application in response to predictable load changes.
 */
export declare class ScheduledAction extends pulumi.CustomResource {
    /**
     * Get an existing ScheduledAction resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ScheduledAction;
    /**
     * Returns true if the given object is an instance of ScheduledAction.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ScheduledAction;
    /**
     * The name of the Auto Scaling group.
     */
    readonly autoScalingGroupName: pulumi.Output<string>;
    /**
     * The desired capacity is the initial capacity of the Auto Scaling group after the scheduled action runs and the capacity it attempts to maintain.
     */
    readonly desiredCapacity: pulumi.Output<number | undefined>;
    /**
     * The latest scheduled start time to return. If scheduled action names are provided, this parameter is ignored.
     */
    readonly endTime: pulumi.Output<string | undefined>;
    /**
     * The minimum size of the Auto Scaling group.
     */
    readonly maxSize: pulumi.Output<number | undefined>;
    /**
     * The minimum size of the Auto Scaling group.
     */
    readonly minSize: pulumi.Output<number | undefined>;
    /**
     * The recurring schedule for the action, in Unix cron syntax format. When StartTime and EndTime are specified with Recurrence , they form the boundaries of when the recurring action starts and stops.
     */
    readonly recurrence: pulumi.Output<string | undefined>;
    /**
     * Auto-generated unique identifier
     */
    readonly scheduledActionName: pulumi.Output<string>;
    /**
     * The earliest scheduled start time to return. If scheduled action names are provided, this parameter is ignored.
     */
    readonly startTime: pulumi.Output<string | undefined>;
    /**
     * The time zone for the cron expression.
     */
    readonly timeZone: pulumi.Output<string | undefined>;
    /**
     * Create a ScheduledAction resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ScheduledActionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ScheduledAction resource.
 */
export interface ScheduledActionArgs {
    /**
     * The name of the Auto Scaling group.
     */
    autoScalingGroupName: pulumi.Input<string>;
    /**
     * The desired capacity is the initial capacity of the Auto Scaling group after the scheduled action runs and the capacity it attempts to maintain.
     */
    desiredCapacity?: pulumi.Input<number>;
    /**
     * The latest scheduled start time to return. If scheduled action names are provided, this parameter is ignored.
     */
    endTime?: pulumi.Input<string>;
    /**
     * The minimum size of the Auto Scaling group.
     */
    maxSize?: pulumi.Input<number>;
    /**
     * The minimum size of the Auto Scaling group.
     */
    minSize?: pulumi.Input<number>;
    /**
     * The recurring schedule for the action, in Unix cron syntax format. When StartTime and EndTime are specified with Recurrence , they form the boundaries of when the recurring action starts and stops.
     */
    recurrence?: pulumi.Input<string>;
    /**
     * The earliest scheduled start time to return. If scheduled action names are provided, this parameter is ignored.
     */
    startTime?: pulumi.Input<string>;
    /**
     * The time zone for the cron expression.
     */
    timeZone?: pulumi.Input<string>;
}
