import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Bedrock::ApplicationInferenceProfile Resource Type
 */
export declare class ApplicationInferenceProfile extends pulumi.CustomResource {
    /**
     * Get an existing ApplicationInferenceProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ApplicationInferenceProfile;
    /**
     * Returns true if the given object is an instance of ApplicationInferenceProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ApplicationInferenceProfile;
    /**
     * Time Stamp
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * Description of the inference profile
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the inference profile.
     */
    readonly inferenceProfileArn: pulumi.Output<string>;
    /**
     * The unique identifier of the inference profile.
     */
    readonly inferenceProfileId: pulumi.Output<string>;
    /**
     * Inference profile identifier. Supports both system-defined inference profile ids, and inference profile ARNs.
     */
    readonly inferenceProfileIdentifier: pulumi.Output<string>;
    /**
     * The name of the inference profile.
     */
    readonly inferenceProfileName: pulumi.Output<string>;
    /**
     * Contains configurations for the inference profile to copy as the resource.
     */
    readonly modelSource: pulumi.Output<outputs.bedrock.ApplicationInferenceProfileInferenceProfileModelSourceProperties | undefined>;
    /**
     * List of model configuration
     */
    readonly models: pulumi.Output<outputs.bedrock.ApplicationInferenceProfileInferenceProfileModel[]>;
    /**
     * The status of the inference profile. `ACTIVE` means that the inference profile is ready to be used.
     */
    readonly status: pulumi.Output<enums.bedrock.ApplicationInferenceProfileInferenceProfileStatus>;
    /**
     * List of Tags
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The type of the inference profile. The following types are possible:
     *
     * - `SYSTEM_DEFINED` – The inference profile is defined by Amazon Bedrock. You can route inference requests across regions with these inference profiles.
     * - `APPLICATION` – The inference profile was created by a user. This type of inference profile can track metrics and costs when invoking the model in it. The inference profile may route requests to one or multiple regions.
     */
    readonly type: pulumi.Output<enums.bedrock.ApplicationInferenceProfileInferenceProfileType>;
    /**
     * Time Stamp
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * Create a ApplicationInferenceProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ApplicationInferenceProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ApplicationInferenceProfile resource.
 */
export interface ApplicationInferenceProfileArgs {
    /**
     * Description of the inference profile
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the inference profile.
     */
    inferenceProfileName?: pulumi.Input<string>;
    /**
     * Contains configurations for the inference profile to copy as the resource.
     */
    modelSource?: pulumi.Input<inputs.bedrock.ApplicationInferenceProfileInferenceProfileModelSourcePropertiesArgs>;
    /**
     * List of Tags
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
