import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::Chatbot::MicrosoftTeamsChannelConfiguration.
 */
export declare function getMicrosoftTeamsChannelConfiguration(args: GetMicrosoftTeamsChannelConfigurationArgs, opts?: pulumi.InvokeOptions): Promise<GetMicrosoftTeamsChannelConfigurationResult>;
export interface GetMicrosoftTeamsChannelConfigurationArgs {
    /**
     * Amazon Resource Name (ARN) of the configuration
     */
    arn: string;
}
export interface GetMicrosoftTeamsChannelConfigurationResult {
    /**
     * Amazon Resource Name (ARN) of the configuration
     */
    readonly arn?: string;
    /**
     * ARNs of Custom Actions to associate with notifications in the provided chat channel.
     */
    readonly customizationResourceArns?: string[];
    /**
     * The list of IAM policy ARNs that are applied as channel guardrails. The AWS managed 'AdministratorAccess' policy is applied as a default if this is not set.
     */
    readonly guardrailPolicies?: string[];
    /**
     * The ARN of the IAM role that defines the permissions for AWS Chatbot
     */
    readonly iamRoleArn?: string;
    /**
     * Specifies the logging level for this configuration:ERROR,INFO or NONE. This property affects the log entries pushed to Amazon CloudWatch logs
     */
    readonly loggingLevel?: string;
    /**
     * ARNs of SNS topics which delivers notifications to AWS Chatbot, for example CloudWatch alarm notifications.
     */
    readonly snsTopicArns?: string[];
    /**
     * The tags to add to the configuration
     */
    readonly tags?: outputs.Tag[];
    /**
     * The id of the Microsoft Teams channel
     */
    readonly teamsChannelId?: string;
    /**
     * The name of the Microsoft Teams channel
     */
    readonly teamsChannelName?: string;
    /**
     * Enables use of a user role requirement in your chat configuration
     */
    readonly userRoleRequired?: boolean;
}
/**
 * Resource schema for AWS::Chatbot::MicrosoftTeamsChannelConfiguration.
 */
export declare function getMicrosoftTeamsChannelConfigurationOutput(args: GetMicrosoftTeamsChannelConfigurationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMicrosoftTeamsChannelConfigurationResult>;
export interface GetMicrosoftTeamsChannelConfigurationOutputArgs {
    /**
     * Amazon Resource Name (ARN) of the configuration
     */
    arn: pulumi.Input<string>;
}
