import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Represents a table that can be associated with collaborations
 */
export declare function getConfiguredTable(args: GetConfiguredTableArgs, opts?: pulumi.InvokeOptions): Promise<GetConfiguredTableResult>;
export interface GetConfiguredTableArgs {
    /**
     * Returns the unique identifier of the specified configured table.
     *
     * Example: `a1b2c3d4-5678-90ab-cdef-EXAMPLE33333`
     */
    configuredTableIdentifier: string;
}
export interface GetConfiguredTableResult {
    /**
     * The analysis method for the configured table.
     *
     * `DIRECT_QUERY` allows SQL queries to be run directly on this table.
     *
     * `DIRECT_JOB` allows PySpark jobs to be run directly on this table.
     *
     * `MULTIPLE` allows both SQL queries and PySpark jobs to be run directly on this table.
     */
    readonly analysisMethod?: enums.cleanrooms.ConfiguredTableAnalysisMethod;
    /**
     * The analysis rule that was created for the configured table.
     */
    readonly analysisRules?: outputs.cleanrooms.ConfiguredTableAnalysisRule[];
    /**
     * Returns the Amazon Resource Name (ARN) of the specified configured table.
     *
     * Example: `arn:aws:cleanrooms:us-east-1:111122223333:configuredtable/a1b2c3d4-5678-90ab-cdef-EXAMPLE11111`
     */
    readonly arn?: string;
    /**
     * Returns the unique identifier of the specified configured table.
     *
     * Example: `a1b2c3d4-5678-90ab-cdef-EXAMPLE33333`
     */
    readonly configuredTableIdentifier?: string;
    /**
     * A description for the configured table.
     */
    readonly description?: string;
    /**
     * A name for the configured table.
     */
    readonly name?: string;
    /**
     * The selected analysis methods for the configured table.
     */
    readonly selectedAnalysisMethods?: enums.cleanrooms.ConfiguredTableSelectedAnalysisMethod[];
    /**
     * An arbitrary set of tags (key-value pairs) for this cleanrooms collaboration.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Represents a table that can be associated with collaborations
 */
export declare function getConfiguredTableOutput(args: GetConfiguredTableOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetConfiguredTableResult>;
export interface GetConfiguredTableOutputArgs {
    /**
     * Returns the unique identifier of the specified configured table.
     *
     * Example: `a1b2c3d4-5678-90ab-cdef-EXAMPLE33333`
     */
    configuredTableIdentifier: pulumi.Input<string>;
}
