import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * This is a CloudFormation resource for activating the first-party AWS::Hooks::GuardHook.
 */
export declare function getGuardHook(args: GetGuardHookArgs, opts?: pulumi.InvokeOptions): Promise<GetGuardHookResult>;
export interface GetGuardHookArgs {
    /**
     * The Amazon Resource Name (ARN) of the activated hook
     */
    hookArn: string;
}
export interface GetGuardHookResult {
    /**
     * Attribute to specify CloudFormation behavior on hook failure.
     */
    readonly failureMode?: enums.cloudformation.GuardHookFailureMode;
    /**
     * The Amazon Resource Name (ARN) of the activated hook
     */
    readonly hookArn?: string;
    /**
     * Attribute to specify which stacks this hook applies to or should get invoked for
     */
    readonly hookStatus?: enums.cloudformation.GuardHookHookStatus;
    /**
     * S3 Bucket where the guard validate report will be uploaded to
     */
    readonly logBucket?: string;
    /**
     * Specifies the S3 location of your input parameters.
     */
    readonly options?: outputs.cloudformation.OptionsProperties;
    /**
     * Specifies the S3 location of your Guard rules.
     */
    readonly ruleLocation?: outputs.cloudformation.GuardHookS3Location;
    /**
     * Filters to allow hooks to target specific stack attributes
     */
    readonly stackFilters?: outputs.cloudformation.StackFiltersProperties;
    /**
     * Attribute to specify which targets should invoke the hook
     */
    readonly targetFilters?: outputs.cloudformation.TargetFilters0Properties | outputs.cloudformation.TargetFilters1Properties;
    /**
     * Which operations should this Hook run against? Resource changes, stacks or change sets.
     */
    readonly targetOperations?: enums.cloudformation.GuardHookTargetOperation[];
}
/**
 * This is a CloudFormation resource for activating the first-party AWS::Hooks::GuardHook.
 */
export declare function getGuardHookOutput(args: GetGuardHookOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetGuardHookResult>;
export interface GetGuardHookOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the activated hook
     */
    hookArn: pulumi.Input<string>;
}
