import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The request to create a new origin access identity (OAI). An origin access identity is a special CloudFront user that you can associate with Amazon S3 origins, so that you can secure all or just some of your Amazon S3 content. For more information, see [Restricting Access to Amazon S3 Content by Using an Origin Access Identity](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/private-content-restricting-access-to-s3.html) in the *Amazon CloudFront Developer Guide*.
 */
export declare function getCloudFrontOriginAccessIdentity(args: GetCloudFrontOriginAccessIdentityArgs, opts?: pulumi.InvokeOptions): Promise<GetCloudFrontOriginAccessIdentityResult>;
export interface GetCloudFrontOriginAccessIdentityArgs {
    /**
     * The ID for the origin access identity, for example, `E74FTE3AJFJ256A` .
     */
    id: string;
}
export interface GetCloudFrontOriginAccessIdentityResult {
    /**
     * The current configuration information for the identity.
     */
    readonly cloudFrontOriginAccessIdentityConfig?: outputs.cloudfront.CloudFrontOriginAccessIdentityConfig;
    /**
     * The ID for the origin access identity, for example, `E74FTE3AJFJ256A` .
     */
    readonly id?: string;
    /**
     * The Amazon S3 canonical user ID for the origin access identity, used when giving the origin access identity read permission to an object in Amazon S3. For example: `b970b42360b81c8ddbd79d2f5df0069ba9033c8a79655752abe380cd6d63ba8bcf23384d568fcf89fc49700b5e11a0fd` .
     */
    readonly s3CanonicalUserId?: string;
}
/**
 * The request to create a new origin access identity (OAI). An origin access identity is a special CloudFront user that you can associate with Amazon S3 origins, so that you can secure all or just some of your Amazon S3 content. For more information, see [Restricting Access to Amazon S3 Content by Using an Origin Access Identity](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/private-content-restricting-access-to-s3.html) in the *Amazon CloudFront Developer Guide*.
 */
export declare function getCloudFrontOriginAccessIdentityOutput(args: GetCloudFrontOriginAccessIdentityOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCloudFrontOriginAccessIdentityResult>;
export interface GetCloudFrontOriginAccessIdentityOutputArgs {
    /**
     * The ID for the origin access identity, for example, `E74FTE3AJFJ256A` .
     */
    id: pulumi.Input<string>;
}
