import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::CodePipeline::CustomActionType resource creates a custom action for activities that aren't included in the CodePipeline default actions, such as running an internally developed build process or a test suite. You can use these custom actions in the stage of a pipeline.
 */
export declare class CustomActionType extends pulumi.CustomResource {
    /**
     * Get an existing CustomActionType resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): CustomActionType;
    /**
     * Returns true if the given object is an instance of CustomActionType.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CustomActionType;
    readonly awsId: pulumi.Output<string>;
    /**
     * The category of the custom action, such as a build action or a test action.
     */
    readonly category: pulumi.Output<string>;
    /**
     * The configuration properties for the custom action.
     */
    readonly configurationProperties: pulumi.Output<outputs.codepipeline.CustomActionTypeConfigurationProperties[] | undefined>;
    /**
     * The details of the input artifact for the action, such as its commit ID.
     */
    readonly inputArtifactDetails: pulumi.Output<outputs.codepipeline.CustomActionTypeArtifactDetails>;
    /**
     * The details of the output artifact of the action, such as its commit ID.
     */
    readonly outputArtifactDetails: pulumi.Output<outputs.codepipeline.CustomActionTypeArtifactDetails>;
    /**
     * The provider of the service used in the custom action, such as AWS CodeDeploy.
     */
    readonly provider: pulumi.Output<string>;
    /**
     * URLs that provide users information about this custom action.
     */
    readonly settings: pulumi.Output<outputs.codepipeline.CustomActionTypeSettings | undefined>;
    /**
     * Any tags assigned to the custom action.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The version identifier of the custom action.
     */
    readonly version: pulumi.Output<string>;
    /**
     * Create a CustomActionType resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CustomActionTypeArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a CustomActionType resource.
 */
export interface CustomActionTypeArgs {
    /**
     * The category of the custom action, such as a build action or a test action.
     */
    category: pulumi.Input<string>;
    /**
     * The configuration properties for the custom action.
     */
    configurationProperties?: pulumi.Input<pulumi.Input<inputs.codepipeline.CustomActionTypeConfigurationPropertiesArgs>[]>;
    /**
     * The details of the input artifact for the action, such as its commit ID.
     */
    inputArtifactDetails: pulumi.Input<inputs.codepipeline.CustomActionTypeArtifactDetailsArgs>;
    /**
     * The details of the output artifact of the action, such as its commit ID.
     */
    outputArtifactDetails: pulumi.Input<inputs.codepipeline.CustomActionTypeArtifactDetailsArgs>;
    /**
     * The provider of the service used in the custom action, such as AWS CodeDeploy.
     */
    provider: pulumi.Input<string>;
    /**
     * URLs that provide users information about this custom action.
     */
    settings?: pulumi.Input<inputs.codepipeline.CustomActionTypeSettingsArgs>;
    /**
     * Any tags assigned to the custom action.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The version identifier of the custom action.
     */
    version: pulumi.Input<string>;
}
