import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Connect::ContactFlow
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const flow = new aws_native.connect.ContactFlow("flow", {
 *     name: "ExampleFlow",
 *     description: "flow created using cfn",
 *     instanceArn: "arn:aws:connect:region-name:aws-account-id:instance/instance-arn",
 *     type: aws_native.connect.ContactFlowType.ContactFlow,
 *     content: "ExampleFlow content(JSON) using Amazon Connect Flow Language.",
 *     tags: [{
 *         key: "testkey",
 *         value: "testValue",
 *     }],
 * });
 *
 * ```
 */
export declare class ContactFlow extends pulumi.CustomResource {
    /**
     * Get an existing ContactFlow resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ContactFlow;
    /**
     * Returns true if the given object is an instance of ContactFlow.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ContactFlow;
    /**
     * The identifier of the contact flow (ARN).
     */
    readonly contactFlowArn: pulumi.Output<string>;
    /**
     * The content of the contact flow in JSON format.
     */
    readonly content: pulumi.Output<string>;
    /**
     * The description of the contact flow.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The identifier of the Amazon Connect instance (ARN).
     */
    readonly instanceArn: pulumi.Output<string>;
    /**
     * The name of the contact flow.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The state of the contact flow.
     */
    readonly state: pulumi.Output<enums.connect.ContactFlowState | undefined>;
    /**
     * One or more tags.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The type of the contact flow.
     */
    readonly type: pulumi.Output<enums.connect.ContactFlowType>;
    /**
     * Create a ContactFlow resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ContactFlowArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ContactFlow resource.
 */
export interface ContactFlowArgs {
    /**
     * The content of the contact flow in JSON format.
     */
    content: pulumi.Input<string>;
    /**
     * The description of the contact flow.
     */
    description?: pulumi.Input<string>;
    /**
     * The identifier of the Amazon Connect instance (ARN).
     */
    instanceArn: pulumi.Input<string>;
    /**
     * The name of the contact flow.
     */
    name?: pulumi.Input<string>;
    /**
     * The state of the contact flow.
     */
    state?: pulumi.Input<enums.connect.ContactFlowState>;
    /**
     * One or more tags.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The type of the contact flow.
     */
    type: pulumi.Input<enums.connect.ContactFlowType>;
}
