import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::DataSync::StorageSystem.
 */
export declare function getStorageSystem(args: GetStorageSystemArgs, opts?: pulumi.InvokeOptions): Promise<GetStorageSystemResult>;
export interface GetStorageSystemArgs {
    /**
     * The ARN of the on-premises storage system added to DataSync Discovery.
     */
    storageSystemArn: string;
}
export interface GetStorageSystemResult {
    /**
     * The ARN of the DataSync agent that connects to and reads from the on-premises storage system's management interface.
     */
    readonly agentArns?: string[];
    /**
     * The ARN of the Amazon CloudWatch log group used to monitor and log discovery job events.
     */
    readonly cloudWatchLogGroupArn?: string;
    /**
     * Indicates whether the DataSync agent can access the on-premises storage system.
     */
    readonly connectivityStatus?: enums.datasync.StorageSystemConnectivityStatus;
    /**
     * A familiar name for the on-premises storage system.
     */
    readonly name?: string;
    /**
     * The ARN of a secret stored by AWS Secrets Manager.
     */
    readonly secretsManagerArn?: string;
    /**
     * Specifies the server name and network port required to connect with the management interface of your on-premises storage system.
     */
    readonly serverConfiguration?: outputs.datasync.StorageSystemServerConfiguration;
    /**
     * The ARN of the on-premises storage system added to DataSync Discovery.
     */
    readonly storageSystemArn?: string;
    /**
     * The type of on-premises storage system that DataSync Discovery will analyze.
     */
    readonly systemType?: enums.datasync.StorageSystemSystemType;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource schema for AWS::DataSync::StorageSystem.
 */
export declare function getStorageSystemOutput(args: GetStorageSystemOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetStorageSystemResult>;
export interface GetStorageSystemOutputArgs {
    /**
     * The ARN of the on-premises storage system added to DataSync Discovery.
     */
    storageSystemArn: pulumi.Input<string>;
}
