import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::DataSync::LocationFSxONTAP.
 */
export declare class LocationFSxOntap extends pulumi.CustomResource {
    /**
     * Get an existing LocationFSxOntap resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): LocationFSxOntap;
    /**
     * Returns true if the given object is an instance of LocationFSxOntap.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LocationFSxOntap;
    /**
     * The Amazon Resource Name (ARN) for the FSx ONAP file system.
     */
    readonly fsxFilesystemArn: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the Amazon FSx ONTAP file system location that is created.
     */
    readonly locationArn: pulumi.Output<string>;
    /**
     * The URL of the FSx ONTAP file system that was described.
     */
    readonly locationUri: pulumi.Output<string>;
    /**
     * Specifies the data transfer protocol that DataSync uses to access your Amazon FSx file system.
     */
    readonly protocol: pulumi.Output<outputs.datasync.LocationFSxOntapProtocol | undefined>;
    /**
     * The ARNs of the security groups that are to use to configure the FSx ONTAP file system.
     */
    readonly securityGroupArns: pulumi.Output<string[]>;
    /**
     * The Amazon Resource Name (ARN) for the FSx ONTAP SVM.
     */
    readonly storageVirtualMachineArn: pulumi.Output<string>;
    /**
     * A subdirectory in the location's path.
     */
    readonly subdirectory: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a LocationFSxOntap resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LocationFSxOntapArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a LocationFSxOntap resource.
 */
export interface LocationFSxOntapArgs {
    /**
     * Specifies the data transfer protocol that DataSync uses to access your Amazon FSx file system.
     */
    protocol?: pulumi.Input<inputs.datasync.LocationFSxOntapProtocolArgs>;
    /**
     * The ARNs of the security groups that are to use to configure the FSx ONTAP file system.
     */
    securityGroupArns: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Amazon Resource Name (ARN) for the FSx ONTAP SVM.
     */
    storageVirtualMachineArn: pulumi.Input<string>;
    /**
     * A subdirectory in the location's path.
     */
    subdirectory?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
