import * as pulumi from "@pulumi/pulumi";
/**
 * A domain unit enables you to easily organize your assets and other domain entities under specific business units and teams.
 */
export declare function getDomainUnit(args: GetDomainUnitArgs, opts?: pulumi.InvokeOptions): Promise<GetDomainUnitResult>;
export interface GetDomainUnitArgs {
    /**
     * The ID of the domain where the domain unit was created.
     */
    domainId: string;
    /**
     * The ID of the domain unit.
     */
    id: string;
}
export interface GetDomainUnitResult {
    /**
     * The timestamp at which the domain unit was created.
     */
    readonly createdAt?: string;
    /**
     * The description of the domain unit.
     */
    readonly description?: string;
    /**
     * The ID of the domain where the domain unit was created.
     */
    readonly domainId?: string;
    /**
     * The ID of the domain unit.
     */
    readonly id?: string;
    /**
     * The identifier of the domain unit that you want to get.
     */
    readonly identifier?: string;
    /**
     * The timestamp at which the domain unit was last updated.
     */
    readonly lastUpdatedAt?: string;
    /**
     * The name of the domain unit.
     */
    readonly name?: string;
    /**
     * The ID of the parent domain unit.
     */
    readonly parentDomainUnitId?: string;
}
/**
 * A domain unit enables you to easily organize your assets and other domain entities under specific business units and teams.
 */
export declare function getDomainUnitOutput(args: GetDomainUnitOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDomainUnitResult>;
export interface GetDomainUnitOutputArgs {
    /**
     * The ID of the domain where the domain unit was created.
     */
    domainId: pulumi.Input<string>;
    /**
     * The ID of the domain unit.
     */
    id: pulumi.Input<string>;
}
