import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * AWS Datazone Environment Profile is pre-configured set of resources and blueprints that provide reusable templates for creating environments.
 */
export declare function getEnvironmentProfile(args: GetEnvironmentProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetEnvironmentProfileResult>;
export interface GetEnvironmentProfileArgs {
    /**
     * The ID of the Amazon DataZone domain in which this environment profile is created.
     */
    domainId: string;
    /**
     * The ID of this Amazon DataZone environment profile.
     */
    id: string;
}
export interface GetEnvironmentProfileResult {
    /**
     * The AWS account in which the Amazon DataZone environment is created.
     */
    readonly awsAccountId?: string;
    /**
     * The AWS region in which this environment profile is created.
     */
    readonly awsAccountRegion?: string;
    /**
     * The timestamp of when this environment profile was created.
     */
    readonly createdAt?: string;
    /**
     * The Amazon DataZone user who created this environment profile.
     */
    readonly createdBy?: string;
    /**
     * The description of this Amazon DataZone environment profile.
     */
    readonly description?: string;
    /**
     * The ID of the Amazon DataZone domain in which this environment profile is created.
     */
    readonly domainId?: string;
    /**
     * The ID of the blueprint with which this environment profile is created.
     */
    readonly environmentBlueprintId?: string;
    /**
     * The ID of this Amazon DataZone environment profile.
     */
    readonly id?: string;
    /**
     * The name of this Amazon DataZone environment profile.
     */
    readonly name?: string;
    /**
     * The identifier of the project in which to create the environment profile.
     */
    readonly projectId?: string;
    /**
     * The timestamp of when this environment profile was updated.
     */
    readonly updatedAt?: string;
    /**
     * The user parameters of this Amazon DataZone environment profile.
     */
    readonly userParameters?: outputs.datazone.EnvironmentProfileEnvironmentParameter[];
}
/**
 * AWS Datazone Environment Profile is pre-configured set of resources and blueprints that provide reusable templates for creating environments.
 */
export declare function getEnvironmentProfileOutput(args: GetEnvironmentProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetEnvironmentProfileResult>;
export interface GetEnvironmentProfileOutputArgs {
    /**
     * The ID of the Amazon DataZone domain in which this environment profile is created.
     */
    domainId: pulumi.Input<string>;
    /**
     * The ID of this Amazon DataZone environment profile.
     */
    id: pulumi.Input<string>;
}
