import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for a Device Farm Instance Profile
 */
export declare class InstanceProfile extends pulumi.CustomResource {
    /**
     * Get an existing InstanceProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): InstanceProfile;
    /**
     * Returns true if the given object is an instance of InstanceProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is InstanceProfile;
    /**
     * The Amazon Resource Name (ARN) of the instance profile. See [Amazon resource names](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html) in the *General Reference guide* .
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The description of the instance profile.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * An array of strings containing the list of app packages that should not be cleaned up from the device after a test run completes.
     *
     * The list of packages is considered only if you set `packageCleanup` to `true` .
     */
    readonly excludeAppPackagesFromCleanup: pulumi.Output<string[] | undefined>;
    /**
     * The name of the instance profile.
     */
    readonly name: pulumi.Output<string>;
    /**
     * When set to `true` , Device Farm removes app packages after a test run. The default value is `false` for private devices.
     */
    readonly packageCleanup: pulumi.Output<boolean | undefined>;
    /**
     * When set to `true` , Device Farm reboots the instance after a test run. The default value is `true` .
     */
    readonly rebootAfterUse: pulumi.Output<boolean | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) in the *guide* .
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a InstanceProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: InstanceProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a InstanceProfile resource.
 */
export interface InstanceProfileArgs {
    /**
     * The description of the instance profile.
     */
    description?: pulumi.Input<string>;
    /**
     * An array of strings containing the list of app packages that should not be cleaned up from the device after a test run completes.
     *
     * The list of packages is considered only if you set `packageCleanup` to `true` .
     */
    excludeAppPackagesFromCleanup?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The name of the instance profile.
     */
    name?: pulumi.Input<string>;
    /**
     * When set to `true` , Device Farm removes app packages after a test run. The default value is `false` for private devices.
     */
    packageCleanup?: pulumi.Input<boolean>;
    /**
     * When set to `true` , Device Farm reboots the instance after a test run. The default value is `true` .
     */
    rebootAfterUse?: pulumi.Input<boolean>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) in the *guide* .
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
