import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A replication configuration that you later provide to configure and start a AWS DMS Serverless replication
 */
export declare class ReplicationConfig extends pulumi.CustomResource {
    /**
     * Get an existing ReplicationConfig resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ReplicationConfig;
    /**
     * Returns true if the given object is an instance of ReplicationConfig.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ReplicationConfig;
    /**
     * Configuration parameters for provisioning an AWS DMS Serverless replication.
     */
    readonly computeConfig: pulumi.Output<outputs.dms.ReplicationConfigComputeConfig>;
    /**
     * The Amazon Resource Name (ARN) of the Replication Config
     */
    readonly replicationConfigArn: pulumi.Output<string>;
    /**
     * A unique identifier of replication configuration
     */
    readonly replicationConfigIdentifier: pulumi.Output<string>;
    /**
     * JSON settings for Servereless replications that are provisioned using this replication configuration
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::DMS::ReplicationConfig` for more information about the expected schema for this property.
     */
    readonly replicationSettings: pulumi.Output<any | undefined>;
    /**
     * The type of AWS DMS Serverless replication to provision using this replication configuration
     */
    readonly replicationType: pulumi.Output<enums.dms.ReplicationConfigReplicationType>;
    /**
     * A unique value or name that you get set for a given resource that can be used to construct an Amazon Resource Name (ARN) for that resource
     */
    readonly resourceIdentifier: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the source endpoint for this AWS DMS Serverless replication configuration
     */
    readonly sourceEndpointArn: pulumi.Output<string>;
    /**
     * JSON settings for specifying supplemental data
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::DMS::ReplicationConfig` for more information about the expected schema for this property.
     */
    readonly supplementalSettings: pulumi.Output<any | undefined>;
    /**
     * JSON table mappings for AWS DMS Serverless replications that are provisioned using this replication configuration
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::DMS::ReplicationConfig` for more information about the expected schema for this property.
     */
    readonly tableMappings: pulumi.Output<any>;
    /**
     * <p>Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.</p>
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the target endpoint for this AWS DMS Serverless replication configuration
     */
    readonly targetEndpointArn: pulumi.Output<string>;
    /**
     * Create a ReplicationConfig resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ReplicationConfigArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ReplicationConfig resource.
 */
export interface ReplicationConfigArgs {
    /**
     * Configuration parameters for provisioning an AWS DMS Serverless replication.
     */
    computeConfig: pulumi.Input<inputs.dms.ReplicationConfigComputeConfigArgs>;
    /**
     * A unique identifier of replication configuration
     */
    replicationConfigIdentifier: pulumi.Input<string>;
    /**
     * JSON settings for Servereless replications that are provisioned using this replication configuration
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::DMS::ReplicationConfig` for more information about the expected schema for this property.
     */
    replicationSettings?: any;
    /**
     * The type of AWS DMS Serverless replication to provision using this replication configuration
     */
    replicationType: pulumi.Input<enums.dms.ReplicationConfigReplicationType>;
    /**
     * A unique value or name that you get set for a given resource that can be used to construct an Amazon Resource Name (ARN) for that resource
     */
    resourceIdentifier?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the source endpoint for this AWS DMS Serverless replication configuration
     */
    sourceEndpointArn: pulumi.Input<string>;
    /**
     * JSON settings for specifying supplemental data
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::DMS::ReplicationConfig` for more information about the expected schema for this property.
     */
    supplementalSettings?: any;
    /**
     * JSON table mappings for AWS DMS Serverless replications that are provisioned using this replication configuration
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::DMS::ReplicationConfig` for more information about the expected schema for this property.
     */
    tableMappings: any;
    /**
     * <p>Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.</p>
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The Amazon Resource Name (ARN) of the target endpoint for this AWS DMS Serverless replication configuration
     */
    targetEndpointArn: pulumi.Input<string>;
}
