import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for Local Gateway Route Table which describes a route table for a local gateway.
 */
export declare class LocalGatewayRouteTable extends pulumi.CustomResource {
    /**
     * Get an existing LocalGatewayRouteTable resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): LocalGatewayRouteTable;
    /**
     * Returns true if the given object is an instance of LocalGatewayRouteTable.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LocalGatewayRouteTable;
    /**
     * The ID of the local gateway.
     */
    readonly localGatewayId: pulumi.Output<string>;
    /**
     * The ARN of the local gateway route table.
     */
    readonly localGatewayRouteTableArn: pulumi.Output<string>;
    /**
     * The ID of the local gateway route table.
     */
    readonly localGatewayRouteTableId: pulumi.Output<string>;
    /**
     * The mode of the local gateway route table.
     */
    readonly mode: pulumi.Output<string | undefined>;
    /**
     * The ARN of the outpost.
     */
    readonly outpostArn: pulumi.Output<string>;
    /**
     * The owner of the local gateway route table.
     */
    readonly ownerId: pulumi.Output<string>;
    /**
     * The state of the local gateway route table.
     */
    readonly state: pulumi.Output<string>;
    /**
     * The tags for the local gateway route table.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a LocalGatewayRouteTable resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LocalGatewayRouteTableArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a LocalGatewayRouteTable resource.
 */
export interface LocalGatewayRouteTableArgs {
    /**
     * The ID of the local gateway.
     */
    localGatewayId: pulumi.Input<string>;
    /**
     * The mode of the local gateway route table.
     */
    mode?: pulumi.Input<string>;
    /**
     * The tags for the local gateway route table.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
