import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::ECS::CapacityProvider.
 */
export declare function getCapacityProvider(args: GetCapacityProviderArgs, opts?: pulumi.InvokeOptions): Promise<GetCapacityProviderResult>;
export interface GetCapacityProviderArgs {
    /**
     * The name of the capacity provider. If a name is specified, it cannot start with `aws` , `ecs` , or `fargate` . If no name is specified, a default name in the `CFNStackName-CFNResourceName-RandomString` format is used.
     */
    name: string;
}
export interface GetCapacityProviderResult {
    /**
     * The Auto Scaling group settings for the capacity provider.
     */
    readonly autoScalingGroupProvider?: outputs.ecs.CapacityProviderAutoScalingGroupProvider;
    /**
     * The metadata that you apply to the capacity provider to help you categorize and organize it. Each tag consists of a key and an optional value. You define both.
     *
     * The following basic restrictions apply to tags:
     *
     * - Maximum number of tags per resource - 50
     * - For each resource, each tag key must be unique, and each tag key can have only one value.
     * - Maximum key length - 128 Unicode characters in UTF-8
     * - Maximum value length - 256 Unicode characters in UTF-8
     * - If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.
     * - Tag keys and values are case-sensitive.
     * - Do not use `aws:` , `AWS:` , or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for AWS use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::ECS::CapacityProvider.
 */
export declare function getCapacityProviderOutput(args: GetCapacityProviderOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCapacityProviderResult>;
export interface GetCapacityProviderOutputArgs {
    /**
     * The name of the capacity provider. If a name is specified, it cannot start with `aws` , `ecs` , or `fargate` . If no name is specified, a default name in the `CFNStackName-CFNResourceName-RandomString` format is used.
     */
    name: pulumi.Input<string>;
}
