import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Specifies an Application Load Balancer, a Network Load Balancer, or a Gateway Load Balancer.
 */
export declare function getLoadBalancer(args: GetLoadBalancerArgs, opts?: pulumi.InvokeOptions): Promise<GetLoadBalancerResult>;
export interface GetLoadBalancerArgs {
    /**
     * The Amazon Resource Name (ARN) of the load balancer.
     */
    loadBalancerArn: string;
}
export interface GetLoadBalancerResult {
    /**
     * The ID of the Amazon Route 53 hosted zone associated with the load balancer. For example, `Z2P70J7EXAMPLE` .
     */
    readonly canonicalHostedZoneId?: string;
    /**
     * The DNS name for the load balancer. For example, `my-load-balancer-424835706.us-west-2.elb.amazonaws.com` .
     */
    readonly dnsName?: string;
    /**
     * [Network Load Balancers with UDP listeners] Indicates whether to use an IPv6 prefix from each subnet for source NAT. The IP address type must be ``dualstack``. The default value is ``off``.
     */
    readonly enablePrefixForIpv6SourceNat?: string;
    /**
     * Indicates whether to evaluate inbound security group rules for traffic sent to a Network Load Balancer through privatelink. The default is ``on``.
     */
    readonly enforceSecurityGroupInboundRulesOnPrivateLinkTraffic?: string;
    /**
     * The IP address type. Internal load balancers must use ``ipv4``.
     *  [Application Load Balancers] The possible values are ``ipv4`` (IPv4 addresses), ``dualstack`` (IPv4 and IPv6 addresses), and ``dualstack-without-public-ipv4`` (public IPv6 addresses and private IPv4 and IPv6 addresses).
     *  Application Load Balancer authentication supports IPv4 addresses only when connecting to an Identity Provider (IdP) or Amazon Cognito endpoint. Without a public IPv4 address the load balancer can't complete the authentication process, resulting in HTTP 500 errors.
     *  [Network Load Balancers and Gateway Load Balancers] The possible values are ``ipv4`` (IPv4 addresses) and ``dualstack`` (IPv4 and IPv6 addresses).
     */
    readonly ipAddressType?: string;
    /**
     * The ID of the IPv4 IPAM pool.
     */
    readonly ipv4IpamPoolId?: string;
    /**
     * The Amazon Resource Name (ARN) of the load balancer.
     */
    readonly loadBalancerArn?: string;
    /**
     * The load balancer attributes.
     */
    readonly loadBalancerAttributes?: outputs.elasticloadbalancingv2.LoadBalancerAttribute[];
    /**
     * The full name of the load balancer. For example, `app/my-load-balancer/50dc6c495c0c9188` .
     */
    readonly loadBalancerFullName?: string;
    /**
     * The name of the load balancer. For example, `my-load-balancer` .
     */
    readonly loadBalancerName?: string;
    /**
     * The minimum capacity for a load balancer.
     */
    readonly minimumLoadBalancerCapacity?: outputs.elasticloadbalancingv2.LoadBalancerMinimumLoadBalancerCapacity;
    /**
     * [Application Load Balancers and Network Load Balancers] The IDs of the security groups for the load balancer.
     */
    readonly securityGroups?: string[];
    /**
     * The IDs of the subnets. You can specify only one subnet per Availability Zone. You must specify either subnets or subnet mappings, but not both.
     *  [Application Load Balancers] You must specify subnets from at least two Availability Zones. You can't specify Elastic IP addresses for your subnets.
     *  [Application Load Balancers on Outposts] You must specify one Outpost subnet.
     *  [Application Load Balancers on Local Zones] You can specify subnets from one or more Local Zones.
     *  [Network Load Balancers] You can specify subnets from one or more Availability Zones. You can specify one Elastic IP address per subnet if you need static IP addresses for your internet-facing load balancer. For internal load balancers, you can specify one private IP address per subnet from the IPv4 range of the subnet. For internet-facing load balancer, you can specify one IPv6 address per subnet.
     *  [Gateway Load Balancers] You can specify subnets from one or more Availability Zones. You can't specify Elastic IP addresses for your subnets.
     */
    readonly subnetMappings?: outputs.elasticloadbalancingv2.LoadBalancerSubnetMapping[];
    /**
     * The IDs of the subnets. You can specify only one subnet per Availability Zone. You must specify either subnets or subnet mappings, but not both. To specify an Elastic IP address, specify subnet mappings instead of subnets.
     *  [Application Load Balancers] You must specify subnets from at least two Availability Zones.
     *  [Application Load Balancers on Outposts] You must specify one Outpost subnet.
     *  [Application Load Balancers on Local Zones] You can specify subnets from one or more Local Zones.
     *  [Network Load Balancers and Gateway Load Balancers] You can specify subnets from one or more Availability Zones.
     */
    readonly subnets?: string[];
    /**
     * The tags to assign to the load balancer.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Specifies an Application Load Balancer, a Network Load Balancer, or a Gateway Load Balancer.
 */
export declare function getLoadBalancerOutput(args: GetLoadBalancerOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetLoadBalancerResult>;
export interface GetLoadBalancerOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the load balancer.
     */
    loadBalancerArn: pulumi.Input<string>;
}
