import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::ElasticLoadBalancingV2::TrustStore
 */
export declare class TrustStore extends pulumi.CustomResource {
    /**
     * Get an existing TrustStore resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TrustStore;
    /**
     * Returns true if the given object is an instance of TrustStore.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TrustStore;
    /**
     * The name of the S3 bucket to fetch the CA certificate bundle from.
     */
    readonly caCertificatesBundleS3Bucket: pulumi.Output<string | undefined>;
    /**
     * The name of the S3 object to fetch the CA certificate bundle from.
     */
    readonly caCertificatesBundleS3Key: pulumi.Output<string | undefined>;
    /**
     * The version of the S3 bucket that contains the CA certificate bundle.
     */
    readonly caCertificatesBundleS3ObjectVersion: pulumi.Output<string | undefined>;
    /**
     * The name of the trust store.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * The number of certificates associated with the trust store.
     */
    readonly numberOfCaCertificates: pulumi.Output<number>;
    /**
     * The status of the trust store, could be either of ACTIVE or CREATING.
     */
    readonly status: pulumi.Output<string>;
    /**
     * The tags to assign to the trust store.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the trust store.
     */
    readonly trustStoreArn: pulumi.Output<string>;
    /**
     * Create a TrustStore resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: TrustStoreArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TrustStore resource.
 */
export interface TrustStoreArgs {
    /**
     * The name of the S3 bucket to fetch the CA certificate bundle from.
     */
    caCertificatesBundleS3Bucket?: pulumi.Input<string>;
    /**
     * The name of the S3 object to fetch the CA certificate bundle from.
     */
    caCertificatesBundleS3Key?: pulumi.Input<string>;
    /**
     * The version of the S3 bucket that contains the CA certificate bundle.
     */
    caCertificatesBundleS3ObjectVersion?: pulumi.Input<string>;
    /**
     * The name of the trust store.
     */
    name?: pulumi.Input<string>;
    /**
     * The tags to assign to the trust store.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
