import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Glue::Job
 */
export declare function getJob(args: GetJobArgs, opts?: pulumi.InvokeOptions): Promise<GetJobResult>;
export interface GetJobArgs {
    /**
     * The name you assign to the job definition
     */
    name: string;
}
export interface GetJobResult {
    /**
     * The number of capacity units that are allocated to this job.
     */
    readonly allocatedCapacity?: number;
    /**
     * The code that executes a job.
     */
    readonly command?: outputs.glue.JobCommand;
    /**
     * Specifies the connections used by a job
     */
    readonly connections?: outputs.glue.JobConnectionsList;
    /**
     * The default arguments for this job, specified as name-value pairs.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Glue::Job` for more information about the expected schema for this property.
     */
    readonly defaultArguments?: any;
    /**
     * A description of the job.
     */
    readonly description?: string;
    /**
     * Indicates whether the job is run with a standard or flexible execution class.
     */
    readonly executionClass?: string;
    /**
     * The maximum number of concurrent runs that are allowed for this job.
     */
    readonly executionProperty?: outputs.glue.JobExecutionProperty;
    /**
     * Glue version determines the versions of Apache Spark and Python that AWS Glue supports.
     */
    readonly glueVersion?: string;
    /**
     * Property description not available.
     */
    readonly jobMode?: string;
    /**
     * Property description not available.
     */
    readonly jobRunQueuingEnabled?: boolean;
    /**
     * This field is reserved for future use.
     */
    readonly logUri?: string;
    /**
     * Property description not available.
     */
    readonly maintenanceWindow?: string;
    /**
     * The number of AWS Glue data processing units (DPUs) that can be allocated when this job runs.
     */
    readonly maxCapacity?: number;
    /**
     * The maximum number of times to retry this job after a JobRun fails
     */
    readonly maxRetries?: number;
    /**
     * Non-overridable arguments for this job, specified as name-value pairs.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Glue::Job` for more information about the expected schema for this property.
     */
    readonly nonOverridableArguments?: any;
    /**
     * Specifies configuration properties of a notification.
     */
    readonly notificationProperty?: outputs.glue.JobNotificationProperty;
    /**
     * The number of workers of a defined workerType that are allocated when a job runs.
     */
    readonly numberOfWorkers?: number;
    /**
     * The name or Amazon Resource Name (ARN) of the IAM role associated with this job.
     */
    readonly role?: string;
    /**
     * The name of the SecurityConfiguration structure to be used with this job.
     */
    readonly securityConfiguration?: string;
    /**
     * The tags to use with this job.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Glue::Job` for more information about the expected schema for this property.
     */
    readonly tags?: any;
    /**
     * The maximum time that a job run can consume resources before it is terminated and enters TIMEOUT status.
     */
    readonly timeout?: number;
    /**
     * TThe type of predefined worker that is allocated when a job runs.
     */
    readonly workerType?: enums.glue.JobWorkerType;
}
/**
 * Resource Type definition for AWS::Glue::Job
 */
export declare function getJobOutput(args: GetJobOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetJobResult>;
export interface GetJobOutputArgs {
    /**
     * The name you assign to the job definition
     */
    name: pulumi.Input<string>;
}
