import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::IAM::SAMLProvider
 */
export declare class SamlProvider extends pulumi.CustomResource {
    /**
     * Get an existing SamlProvider resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): SamlProvider;
    /**
     * Returns true if the given object is an instance of SamlProvider.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SamlProvider;
    /**
     * The private key from your external identity provider
     */
    readonly addPrivateKey: pulumi.Output<string | undefined>;
    /**
     * Amazon Resource Name (ARN) of the SAML provider
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The encryption setting for the SAML provider
     */
    readonly assertionEncryptionMode: pulumi.Output<enums.iam.SamlProviderAssertionEncryptionMode | undefined>;
    /**
     * The name of the provider to create.
     *
     * This parameter allows (through its [regex pattern](https://docs.aws.amazon.com/http://wikipedia.org/wiki/regex) ) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * The private key metadata for the SAML provider.
     */
    readonly privateKeyList: pulumi.Output<outputs.iam.SamlProviderSamlPrivateKey[] | undefined>;
    /**
     * The Key ID of the private key to remove
     */
    readonly removePrivateKey: pulumi.Output<string | undefined>;
    /**
     * An XML document generated by an identity provider (IdP) that supports SAML 2.0. The document includes the issuer's name, expiration information, and keys that can be used to validate the SAML authentication response (assertions) that are received from the IdP. You must generate the metadata document using the identity management software that is used as your organization's IdP.
     *
     * For more information, see [About SAML 2.0-based federation](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_saml.html) in the *IAM User Guide*
     */
    readonly samlMetadataDocument: pulumi.Output<string | undefined>;
    /**
     * The unique identifier assigned to the SAML provider
     */
    readonly samlProviderUuid: pulumi.Output<string>;
    /**
     * A list of tags that you want to attach to the new IAM SAML provider. Each tag consists of a key name and an associated value. For more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the *IAM User Guide* .
     *
     * > If any one of the tags is invalid or if you exceed the allowed maximum number of tags, then the entire request fails and the resource is not created.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a SamlProvider resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: SamlProviderArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a SamlProvider resource.
 */
export interface SamlProviderArgs {
    /**
     * The private key from your external identity provider
     */
    addPrivateKey?: pulumi.Input<string>;
    /**
     * The encryption setting for the SAML provider
     */
    assertionEncryptionMode?: pulumi.Input<enums.iam.SamlProviderAssertionEncryptionMode>;
    /**
     * The name of the provider to create.
     *
     * This parameter allows (through its [regex pattern](https://docs.aws.amazon.com/http://wikipedia.org/wiki/regex) ) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
     */
    name?: pulumi.Input<string>;
    /**
     * The private key metadata for the SAML provider.
     */
    privateKeyList?: pulumi.Input<pulumi.Input<inputs.iam.SamlProviderSamlPrivateKeyArgs>[]>;
    /**
     * The Key ID of the private key to remove
     */
    removePrivateKey?: pulumi.Input<string>;
    /**
     * An XML document generated by an identity provider (IdP) that supports SAML 2.0. The document includes the issuer's name, expiration information, and keys that can be used to validate the SAML authentication response (assertions) that are received from the IdP. You must generate the metadata document using the identity management software that is used as your organization's IdP.
     *
     * For more information, see [About SAML 2.0-based federation](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_saml.html) in the *IAM User Guide*
     */
    samlMetadataDocument?: pulumi.Input<string>;
    /**
     * A list of tags that you want to attach to the new IAM SAML provider. Each tag consists of a key name and an associated value. For more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the *IAM User Guide* .
     *
     * > If any one of the tags is invalid or if you exceed the allowed maximum number of tags, then the entire request fails and the resource is not created.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
