import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Registers a CA Certificate in IoT.
 */
export declare class CaCertificate extends pulumi.CustomResource {
    /**
     * Get an existing CaCertificate resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): CaCertificate;
    /**
     * Returns true if the given object is an instance of CaCertificate.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CaCertificate;
    /**
     * Returns the Amazon Resource Name (ARN) for the CA certificate. For example:
     *
     * `{ "Fn::GetAtt": ["MyCACertificate", "Arn"] }`
     *
     * A value similar to the following is returned:
     *
     * `arn:aws:iot:us-east-1:123456789012:cacert/a6be6b84559801927e35a8f901fae08b5971d78d1562e29504ff9663b276a5f5`
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Whether the CA certificate is configured for auto registration of device certificates. Valid values are "ENABLE" and "DISABLE".
     */
    readonly autoRegistrationStatus: pulumi.Output<enums.iot.CaCertificateAutoRegistrationStatus | undefined>;
    /**
     * The CA certificate ID.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The certificate data in PEM format.
     */
    readonly caCertificatePem: pulumi.Output<string>;
    /**
     * The mode of the CA.
     *
     * All the device certificates that are registered using this CA will be registered in the same mode as the CA. For more information about certificate mode for device certificates, see [certificate mode](https://docs.aws.amazon.com//iot/latest/apireference/API_CertificateDescription.html#iot-Type-CertificateDescription-certificateMode) .
     *
     * Valid values are "DEFAULT" and "SNI_ONLY".
     */
    readonly certificateMode: pulumi.Output<enums.iot.CaCertificateCertificateMode | undefined>;
    /**
     * Information about the registration configuration.
     */
    readonly registrationConfig: pulumi.Output<outputs.iot.CaCertificateRegistrationConfig | undefined>;
    /**
     * If true, removes auto registration.
     */
    readonly removeAutoRegistration: pulumi.Output<boolean | undefined>;
    /**
     * The status of the CA certificate.
     *
     * Valid values are "ACTIVE" and "INACTIVE".
     */
    readonly status: pulumi.Output<enums.iot.CaCertificateStatus>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The private key verification certificate.
     */
    readonly verificationCertificatePem: pulumi.Output<string | undefined>;
    /**
     * Create a CaCertificate resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CaCertificateArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a CaCertificate resource.
 */
export interface CaCertificateArgs {
    /**
     * Whether the CA certificate is configured for auto registration of device certificates. Valid values are "ENABLE" and "DISABLE".
     */
    autoRegistrationStatus?: pulumi.Input<enums.iot.CaCertificateAutoRegistrationStatus>;
    /**
     * The certificate data in PEM format.
     */
    caCertificatePem: pulumi.Input<string>;
    /**
     * The mode of the CA.
     *
     * All the device certificates that are registered using this CA will be registered in the same mode as the CA. For more information about certificate mode for device certificates, see [certificate mode](https://docs.aws.amazon.com//iot/latest/apireference/API_CertificateDescription.html#iot-Type-CertificateDescription-certificateMode) .
     *
     * Valid values are "DEFAULT" and "SNI_ONLY".
     */
    certificateMode?: pulumi.Input<enums.iot.CaCertificateCertificateMode>;
    /**
     * Information about the registration configuration.
     */
    registrationConfig?: pulumi.Input<inputs.iot.CaCertificateRegistrationConfigArgs>;
    /**
     * If true, removes auto registration.
     */
    removeAutoRegistration?: pulumi.Input<boolean>;
    /**
     * The status of the CA certificate.
     *
     * Valid values are "ACTIVE" and "INACTIVE".
     */
    status: pulumi.Input<enums.iot.CaCertificateStatus>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The private key verification certificate.
     */
    verificationCertificatePem?: pulumi.Input<string>;
}
