import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Creates a fleet provisioning template.
 */
export declare class ProvisioningTemplate extends pulumi.CustomResource {
    /**
     * Get an existing ProvisioningTemplate resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ProvisioningTemplate;
    /**
     * Returns true if the given object is an instance of ProvisioningTemplate.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ProvisioningTemplate;
    /**
     * The description of the fleet provisioning template.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * True to enable the fleet provisioning template, otherwise false.
     */
    readonly enabled: pulumi.Output<boolean | undefined>;
    /**
     * Creates a pre-provisioning hook template.
     */
    readonly preProvisioningHook: pulumi.Output<outputs.iot.ProvisioningTemplateProvisioningHook | undefined>;
    /**
     * The role ARN for the role associated with the fleet provisioning template. This IoT role grants permission to provision a device.
     */
    readonly provisioningRoleArn: pulumi.Output<string>;
    /**
     * Metadata that can be used to manage the fleet provisioning template.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The ARN that identifies the provisioning template.
     */
    readonly templateArn: pulumi.Output<string>;
    /**
     * The JSON formatted contents of the fleet provisioning template version.
     */
    readonly templateBody: pulumi.Output<string>;
    /**
     * The name of the fleet provisioning template.
     */
    readonly templateName: pulumi.Output<string | undefined>;
    /**
     * The type of the provisioning template.
     */
    readonly templateType: pulumi.Output<enums.iot.ProvisioningTemplateTemplateType | undefined>;
    /**
     * Create a ProvisioningTemplate resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ProvisioningTemplateArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ProvisioningTemplate resource.
 */
export interface ProvisioningTemplateArgs {
    /**
     * The description of the fleet provisioning template.
     */
    description?: pulumi.Input<string>;
    /**
     * True to enable the fleet provisioning template, otherwise false.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * Creates a pre-provisioning hook template.
     */
    preProvisioningHook?: pulumi.Input<inputs.iot.ProvisioningTemplateProvisioningHookArgs>;
    /**
     * The role ARN for the role associated with the fleet provisioning template. This IoT role grants permission to provision a device.
     */
    provisioningRoleArn: pulumi.Input<string>;
    /**
     * Metadata that can be used to manage the fleet provisioning template.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The JSON formatted contents of the fleet provisioning template version.
     */
    templateBody: pulumi.Input<string>;
    /**
     * The name of the fleet provisioning template.
     */
    templateName?: pulumi.Input<string>;
    /**
     * The type of the provisioning template.
     */
    templateType?: pulumi.Input<enums.iot.ProvisioningTemplateTemplateType>;
}
