import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The configuration of the workers, which are the processes that run the connector logic.
 */
export declare class WorkerConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing WorkerConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): WorkerConfiguration;
    /**
     * Returns true if the given object is an instance of WorkerConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is WorkerConfiguration;
    /**
     * A summary description of the worker configuration.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The name of the worker configuration.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Base64 encoded contents of connect-distributed.properties file.
     */
    readonly propertiesFileContent: pulumi.Output<string>;
    /**
     * The description of a revision of the worker configuration.
     */
    readonly revision: pulumi.Output<number>;
    /**
     * A collection of tags associated with a resource
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the custom configuration.
     */
    readonly workerConfigurationArn: pulumi.Output<string>;
    /**
     * Create a WorkerConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: WorkerConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a WorkerConfiguration resource.
 */
export interface WorkerConfigurationArgs {
    /**
     * A summary description of the worker configuration.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the worker configuration.
     */
    name?: pulumi.Input<string>;
    /**
     * Base64 encoded contents of connect-distributed.properties file.
     */
    propertiesFileContent: pulumi.Input<string>;
    /**
     * A collection of tags associated with a resource
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
