import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for AWS::Lightsail::Alarm
 */
export declare function getAlarm(args: GetAlarmArgs, opts?: pulumi.InvokeOptions): Promise<GetAlarmResult>;
export interface GetAlarmArgs {
    /**
     * The name for the alarm. Specify the name of an existing alarm to update, and overwrite the previous configuration of the alarm.
     */
    alarmName: string;
}
export interface GetAlarmResult {
    /**
     * The Amazon Resource Name (ARN) of the alarm.
     */
    readonly alarmArn?: string;
    /**
     * The arithmetic operation to use when comparing the specified statistic to the threshold. The specified statistic value is used as the first operand.
     */
    readonly comparisonOperator?: string;
    /**
     * The contact protocols to use for the alarm, such as Email, SMS (text messaging), or both.
     */
    readonly contactProtocols?: string[];
    /**
     * The number of data points that must be not within the specified threshold to trigger the alarm. If you are setting an "M out of N" alarm, this value (datapointsToAlarm) is the M.
     */
    readonly datapointsToAlarm?: number;
    /**
     * The number of most recent periods over which data is compared to the specified threshold. If you are setting an "M out of N" alarm, this value (evaluationPeriods) is the N.
     */
    readonly evaluationPeriods?: number;
    /**
     * Indicates whether the alarm is enabled. Notifications are enabled by default if you don't specify this parameter.
     */
    readonly notificationEnabled?: boolean;
    /**
     * The alarm states that trigger a notification.
     */
    readonly notificationTriggers?: string[];
    /**
     * The current state of the alarm.
     */
    readonly state?: string;
    /**
     * The value against which the specified statistic is compared.
     */
    readonly threshold?: number;
    /**
     * Sets how this alarm will handle missing data points.
     */
    readonly treatMissingData?: string;
}
/**
 * Resource Type definition for AWS::Lightsail::Alarm
 */
export declare function getAlarmOutput(args: GetAlarmOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAlarmResult>;
export interface GetAlarmOutputArgs {
    /**
     * The name for the alarm. Specify the name of an existing alarm to update, and overwrite the previous configuration of the alarm.
     */
    alarmName: pulumi.Input<string>;
}
