import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::MediaPackage::PackagingConfiguration
 */
export declare class PackagingConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing PackagingConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): PackagingConfiguration;
    /**
     * Returns true if the given object is an instance of PackagingConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is PackagingConfiguration;
    /**
     * The ARN of the PackagingConfiguration.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ID of the PackagingConfiguration.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * A CMAF packaging configuration.
     */
    readonly cmafPackage: pulumi.Output<outputs.mediapackage.PackagingConfigurationCmafPackage | undefined>;
    /**
     * A Dynamic Adaptive Streaming over HTTP (DASH) packaging configuration.
     */
    readonly dashPackage: pulumi.Output<outputs.mediapackage.PackagingConfigurationDashPackage | undefined>;
    /**
     * An HTTP Live Streaming (HLS) packaging configuration.
     */
    readonly hlsPackage: pulumi.Output<outputs.mediapackage.PackagingConfigurationHlsPackage | undefined>;
    /**
     * A Microsoft Smooth Streaming (MSS) PackagingConfiguration.
     */
    readonly mssPackage: pulumi.Output<outputs.mediapackage.PackagingConfigurationMssPackage | undefined>;
    /**
     * The ID of a PackagingGroup.
     */
    readonly packagingGroupId: pulumi.Output<string>;
    /**
     * A collection of tags associated with a resource
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a PackagingConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: PackagingConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a PackagingConfiguration resource.
 */
export interface PackagingConfigurationArgs {
    /**
     * The ID of the PackagingConfiguration.
     */
    awsId: pulumi.Input<string>;
    /**
     * A CMAF packaging configuration.
     */
    cmafPackage?: pulumi.Input<inputs.mediapackage.PackagingConfigurationCmafPackageArgs>;
    /**
     * A Dynamic Adaptive Streaming over HTTP (DASH) packaging configuration.
     */
    dashPackage?: pulumi.Input<inputs.mediapackage.PackagingConfigurationDashPackageArgs>;
    /**
     * An HTTP Live Streaming (HLS) packaging configuration.
     */
    hlsPackage?: pulumi.Input<inputs.mediapackage.PackagingConfigurationHlsPackageArgs>;
    /**
     * A Microsoft Smooth Streaming (MSS) PackagingConfiguration.
     */
    mssPackage?: pulumi.Input<inputs.mediapackage.PackagingConfigurationMssPackageArgs>;
    /**
     * The ID of a PackagingGroup.
     */
    packagingGroupId: pulumi.Input<string>;
    /**
     * A collection of tags associated with a resource
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
