import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::MediaTailor::LiveSource Resource Type
 */
export declare class LiveSource extends pulumi.CustomResource {
    /**
     * Get an existing LiveSource resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): LiveSource;
    /**
     * Returns true if the given object is an instance of LiveSource.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LiveSource;
    /**
     * <p>The ARN of the live source.</p>
     */
    readonly arn: pulumi.Output<string>;
    /**
     * <p>A list of HTTP package configuration parameters for this live source.</p>
     */
    readonly httpPackageConfigurations: pulumi.Output<outputs.mediatailor.LiveSourceHttpPackageConfiguration[]>;
    /**
     * The name that's used to refer to a live source.
     */
    readonly liveSourceName: pulumi.Output<string>;
    /**
     * The name of the source location.
     */
    readonly sourceLocationName: pulumi.Output<string>;
    /**
     * The tags to assign to the live source.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a LiveSource resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LiveSourceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a LiveSource resource.
 */
export interface LiveSourceArgs {
    /**
     * <p>A list of HTTP package configuration parameters for this live source.</p>
     */
    httpPackageConfigurations: pulumi.Input<pulumi.Input<inputs.mediatailor.LiveSourceHttpPackageConfigurationArgs>[]>;
    /**
     * The name that's used to refer to a live source.
     */
    liveSourceName?: pulumi.Input<string>;
    /**
     * The name of the source location.
     */
    sourceLocationName: pulumi.Input<string>;
    /**
     * The tags to assign to the live source.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
