import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for AWS::MSK::ClusterPolicy
 */
export declare class ClusterPolicy extends pulumi.CustomResource {
    /**
     * Get an existing ClusterPolicy resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ClusterPolicy;
    /**
     * Returns true if the given object is an instance of ClusterPolicy.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ClusterPolicy;
    /**
     * The arn of the cluster for the resource policy.
     */
    readonly clusterArn: pulumi.Output<string>;
    /**
     * The current version of the policy attached to the specified cluster
     */
    readonly currentVersion: pulumi.Output<string>;
    /**
     * A policy document containing permissions to add to the specified cluster.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::MSK::ClusterPolicy` for more information about the expected schema for this property.
     */
    readonly policy: pulumi.Output<any>;
    /**
     * Create a ClusterPolicy resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ClusterPolicyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ClusterPolicy resource.
 */
export interface ClusterPolicyArgs {
    /**
     * The arn of the cluster for the resource policy.
     */
    clusterArn: pulumi.Input<string>;
    /**
     * A policy document containing permissions to add to the specified cluster.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::MSK::ClusterPolicy` for more information about the expected schema for this property.
     */
    policy: any;
}
