import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * AWS::Neptune::DBParameterGroup creates a new DB parameter group. This type can be declared in a template and referenced in the DBParameterGroupName parameter of AWS::Neptune::DBInstance
 */
export declare function getDbParameterGroup(args: GetDbParameterGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetDbParameterGroupResult>;
export interface GetDbParameterGroupArgs {
    /**
     * Provides the name of the DB parameter group.
     */
    name: string;
}
export interface GetDbParameterGroupResult {
    /**
     * The parameters to set for this DB parameter group.
     *
     * The parameters are expressed as a JSON object consisting of key-value pairs.
     *
     * Changes to dynamic parameters are applied immediately. During an update, if you have static parameters (whether they were changed or not), it triggers AWS CloudFormation to reboot the associated DB instance without failover.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Neptune::DBParameterGroup` for more information about the expected schema for this property.
     */
    readonly parameters?: any;
    /**
     * An optional array of key-value pairs to apply to this DB parameter group.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * AWS::Neptune::DBParameterGroup creates a new DB parameter group. This type can be declared in a template and referenced in the DBParameterGroupName parameter of AWS::Neptune::DBInstance
 */
export declare function getDbParameterGroupOutput(args: GetDbParameterGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDbParameterGroupResult>;
export interface GetDbParameterGroupOutputArgs {
    /**
     * Provides the name of the DB parameter group.
     */
    name: pulumi.Input<string>;
}
