import * as pulumi from "@pulumi/pulumi";
/**
 * The AWS::NetworkManager::CustomerGatewayAssociation type associates a customer gateway with a device and optionally, with a link.
 */
export declare class CustomerGatewayAssociation extends pulumi.CustomResource {
    /**
     * Get an existing CustomerGatewayAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): CustomerGatewayAssociation;
    /**
     * Returns true if the given object is an instance of CustomerGatewayAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CustomerGatewayAssociation;
    /**
     * The Amazon Resource Name (ARN) of the customer gateway.
     */
    readonly customerGatewayArn: pulumi.Output<string>;
    /**
     * The ID of the device
     */
    readonly deviceId: pulumi.Output<string>;
    /**
     * The ID of the global network.
     */
    readonly globalNetworkId: pulumi.Output<string>;
    /**
     * The ID of the link
     */
    readonly linkId: pulumi.Output<string | undefined>;
    /**
     * Create a CustomerGatewayAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CustomerGatewayAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a CustomerGatewayAssociation resource.
 */
export interface CustomerGatewayAssociationArgs {
    /**
     * The Amazon Resource Name (ARN) of the customer gateway.
     */
    customerGatewayArn: pulumi.Input<string>;
    /**
     * The ID of the device
     */
    deviceId: pulumi.Input<string>;
    /**
     * The ID of the global network.
     */
    globalNetworkId: pulumi.Input<string>;
    /**
     * The ID of the link
     */
    linkId?: pulumi.Input<string>;
}
