import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Resource Schema for AWS::Personalize::DatasetGroup.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myDatasetGroup = new aws_native.personalize.DatasetGroup("myDatasetGroup", {name: "my-dataset-group-name"});
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myDatasetGroup = new aws_native.personalize.DatasetGroup("myDatasetGroup", {name: "my-dataset-group-name"});
 *
 * ```
 */
export declare class DatasetGroup extends pulumi.CustomResource {
    /**
     * Get an existing DatasetGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DatasetGroup;
    /**
     * Returns true if the given object is an instance of DatasetGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DatasetGroup;
    /**
     * The Amazon Resource Name (ARN) of the dataset group.
     */
    readonly datasetGroupArn: pulumi.Output<string>;
    /**
     * The domain of a Domain dataset group.
     */
    readonly domain: pulumi.Output<enums.personalize.DatasetGroupDomain | undefined>;
    /**
     * The Amazon Resource Name(ARN) of a AWS Key Management Service (KMS) key used to encrypt the datasets.
     */
    readonly kmsKeyArn: pulumi.Output<string | undefined>;
    /**
     * The name for the new dataset group.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The ARN of the AWS Identity and Access Management (IAM) role that has permissions to access the AWS Key Management Service (KMS) key. Supplying an IAM role is only valid when also specifying a KMS key.
     */
    readonly roleArn: pulumi.Output<string | undefined>;
    /**
     * Create a DatasetGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: DatasetGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DatasetGroup resource.
 */
export interface DatasetGroupArgs {
    /**
     * The domain of a Domain dataset group.
     */
    domain?: pulumi.Input<enums.personalize.DatasetGroupDomain>;
    /**
     * The Amazon Resource Name(ARN) of a AWS Key Management Service (KMS) key used to encrypt the datasets.
     */
    kmsKeyArn?: pulumi.Input<string>;
    /**
     * The name for the new dataset group.
     */
    name?: pulumi.Input<string>;
    /**
     * The ARN of the AWS Identity and Access Management (IAM) role that has permissions to access the AWS Key Management Service (KMS) key. Supplying an IAM role is only valid when also specifying a KMS key.
     */
    roleArn?: pulumi.Input<string>;
}
