import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::QBusiness::DataSource Resource Type
 */
export declare class DataSource extends pulumi.CustomResource {
    /**
     * Get an existing DataSource resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DataSource;
    /**
     * Returns true if the given object is an instance of DataSource.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DataSource;
    /**
     * The identifier of the Amazon Q Business application the data source will be attached to.
     */
    readonly applicationId: pulumi.Output<string>;
    /**
     * Use this property to specify a JSON or YAML schema with configuration properties specific to your data source connector to connect your data source repository to Amazon Q Business . You must use the JSON or YAML schema provided by Amazon Q .
     *
     * The following links have the configuration properties and schemas for AWS CloudFormation for the following connectors:
     *
     * - [Amazon Simple Storage Service](https://docs.aws.amazon.com/amazonq/latest/qbusiness-ug/s3-cfn.html)
     * - [Amazon Q Web Crawler](https://docs.aws.amazon.com/amazonq/latest/qbusiness-ug/web-crawler-cfn.html)
     *
     * Similarly, you can find configuration templates and properties for your specific data source using the following steps:
     *
     * - Navigate to the [Supported connectors](https://docs.aws.amazon.com/amazonq/latest/business-use-dg/connectors-list.html) page in the Amazon Q Business User Guide, and select the data source connector of your choice.
     * - Then, from that specific data source connector's page, choose the topic containing *Using AWS CloudFormation* to find the schemas for your data source connector, including configuration parameter descriptions and examples.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::QBusiness::DataSource` for more information about the expected schema for this property.
     */
    readonly configuration: pulumi.Output<any>;
    /**
     * The Unix timestamp when the Amazon Q Business data source was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of a data source in an Amazon Q Business application.
     */
    readonly dataSourceArn: pulumi.Output<string>;
    /**
     * The identifier of the Amazon Q Business data source.
     */
    readonly dataSourceId: pulumi.Output<string>;
    /**
     * A description for the data source connector.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The name of the Amazon Q Business data source.
     */
    readonly displayName: pulumi.Output<string>;
    /**
     * Provides the configuration information for altering document metadata and content during the document ingestion process.
     *
     * For more information, see [Custom document enrichment](https://docs.aws.amazon.com/amazonq/latest/business-use-dg/custom-document-enrichment.html) .
     */
    readonly documentEnrichmentConfiguration: pulumi.Output<outputs.qbusiness.DataSourceDocumentEnrichmentConfiguration | undefined>;
    /**
     * The identifier of the index the data source is attached to.
     */
    readonly indexId: pulumi.Output<string>;
    /**
     * The configuration for extracting information from media in documents.
     */
    readonly mediaExtractionConfiguration: pulumi.Output<outputs.qbusiness.DataSourceMediaExtractionConfiguration | undefined>;
    /**
     * The Amazon Resource Name (ARN) of an IAM role with permission to access the data source and required resources.
     */
    readonly roleArn: pulumi.Output<string | undefined>;
    /**
     * The status of the Amazon Q Business data source.
     */
    readonly status: pulumi.Output<enums.qbusiness.DataSourceStatus>;
    /**
     * Sets the frequency for Amazon Q Business to check the documents in your data source repository and update your index. If you don't set a schedule, Amazon Q Business won't periodically update the index.
     *
     * Specify a `cron-` format schedule string or an empty string to indicate that the index is updated on demand. You can't specify the `Schedule` parameter when the `Type` parameter is set to `CUSTOM` . If you do, you receive a `ValidationException` exception.
     */
    readonly syncSchedule: pulumi.Output<string | undefined>;
    /**
     * A list of key-value pairs that identify or categorize the data source connector. You can also use tags to help control access to the data source connector. Tag keys and values can consist of Unicode letters, digits, white space, and any of the following symbols: _ . : / = + - @.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The type of the Amazon Q Business data source.
     */
    readonly type: pulumi.Output<string>;
    /**
     * The Unix timestamp when the Amazon Q Business data source was last updated.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * Configuration information for an Amazon VPC (Virtual Private Cloud) to connect to your data source. For more information, see [Using Amazon VPC with Amazon Q Business connectors](https://docs.aws.amazon.com/amazonq/latest/business-use-dg/connector-vpc.html) .
     */
    readonly vpcConfiguration: pulumi.Output<outputs.qbusiness.DataSourceVpcConfiguration | undefined>;
    /**
     * Create a DataSource resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DataSourceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DataSource resource.
 */
export interface DataSourceArgs {
    /**
     * The identifier of the Amazon Q Business application the data source will be attached to.
     */
    applicationId: pulumi.Input<string>;
    /**
     * Use this property to specify a JSON or YAML schema with configuration properties specific to your data source connector to connect your data source repository to Amazon Q Business . You must use the JSON or YAML schema provided by Amazon Q .
     *
     * The following links have the configuration properties and schemas for AWS CloudFormation for the following connectors:
     *
     * - [Amazon Simple Storage Service](https://docs.aws.amazon.com/amazonq/latest/qbusiness-ug/s3-cfn.html)
     * - [Amazon Q Web Crawler](https://docs.aws.amazon.com/amazonq/latest/qbusiness-ug/web-crawler-cfn.html)
     *
     * Similarly, you can find configuration templates and properties for your specific data source using the following steps:
     *
     * - Navigate to the [Supported connectors](https://docs.aws.amazon.com/amazonq/latest/business-use-dg/connectors-list.html) page in the Amazon Q Business User Guide, and select the data source connector of your choice.
     * - Then, from that specific data source connector's page, choose the topic containing *Using AWS CloudFormation* to find the schemas for your data source connector, including configuration parameter descriptions and examples.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::QBusiness::DataSource` for more information about the expected schema for this property.
     */
    configuration: any;
    /**
     * A description for the data source connector.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the Amazon Q Business data source.
     */
    displayName: pulumi.Input<string>;
    /**
     * Provides the configuration information for altering document metadata and content during the document ingestion process.
     *
     * For more information, see [Custom document enrichment](https://docs.aws.amazon.com/amazonq/latest/business-use-dg/custom-document-enrichment.html) .
     */
    documentEnrichmentConfiguration?: pulumi.Input<inputs.qbusiness.DataSourceDocumentEnrichmentConfigurationArgs>;
    /**
     * The identifier of the index the data source is attached to.
     */
    indexId: pulumi.Input<string>;
    /**
     * The configuration for extracting information from media in documents.
     */
    mediaExtractionConfiguration?: pulumi.Input<inputs.qbusiness.DataSourceMediaExtractionConfigurationArgs>;
    /**
     * The Amazon Resource Name (ARN) of an IAM role with permission to access the data source and required resources.
     */
    roleArn?: pulumi.Input<string>;
    /**
     * Sets the frequency for Amazon Q Business to check the documents in your data source repository and update your index. If you don't set a schedule, Amazon Q Business won't periodically update the index.
     *
     * Specify a `cron-` format schedule string or an empty string to indicate that the index is updated on demand. You can't specify the `Schedule` parameter when the `Type` parameter is set to `CUSTOM` . If you do, you receive a `ValidationException` exception.
     */
    syncSchedule?: pulumi.Input<string>;
    /**
     * A list of key-value pairs that identify or categorize the data source connector. You can also use tags to help control access to the data source connector. Tag keys and values can consist of Unicode letters, digits, white space, and any of the following symbols: _ . : / = + - @.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * Configuration information for an Amazon VPC (Virtual Private Cloud) to connect to your data source. For more information, see [Using Amazon VPC with Amazon Q Business connectors](https://docs.aws.amazon.com/amazonq/latest/business-use-dg/connector-vpc.html) .
     */
    vpcConfiguration?: pulumi.Input<inputs.qbusiness.DataSourceVpcConfigurationArgs>;
}
