import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::Route53Resolver::FirewallDomainList.
 */
export declare class FirewallDomainList extends pulumi.CustomResource {
    /**
     * Get an existing FirewallDomainList resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): FirewallDomainList;
    /**
     * Returns true if the given object is an instance of FirewallDomainList.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is FirewallDomainList;
    /**
     * Arn
     */
    readonly arn: pulumi.Output<string>;
    /**
     * ResourceId
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * Rfc3339TimeString
     */
    readonly creationTime: pulumi.Output<string>;
    /**
     * The id of the creator request.
     */
    readonly creatorRequestId: pulumi.Output<string>;
    /**
     * Count
     */
    readonly domainCount: pulumi.Output<number>;
    /**
     * S3 URL to import domains from.
     */
    readonly domainFileUrl: pulumi.Output<string | undefined>;
    /**
     * A list of the domain lists that you have defined.
     */
    readonly domains: pulumi.Output<string[] | undefined>;
    /**
     * ServicePrincipal
     */
    readonly managedOwnerName: pulumi.Output<string>;
    /**
     * Rfc3339TimeString
     */
    readonly modificationTime: pulumi.Output<string>;
    /**
     * FirewallDomainListName
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * ResolverFirewallDomainList, possible values are COMPLETE, DELETING, UPDATING, COMPLETE_IMPORT_FAILED, IMPORTING, and INACTIVE_OWNER_ACCOUNT_CLOSED.
     */
    readonly status: pulumi.Output<enums.route53resolver.FirewallDomainListStatus>;
    /**
     * FirewallDomainListAssociationStatus
     */
    readonly statusMessage: pulumi.Output<string>;
    /**
     * Tags
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a FirewallDomainList resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: FirewallDomainListArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a FirewallDomainList resource.
 */
export interface FirewallDomainListArgs {
    /**
     * S3 URL to import domains from.
     */
    domainFileUrl?: pulumi.Input<string>;
    /**
     * A list of the domain lists that you have defined.
     */
    domains?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * FirewallDomainListName
     */
    name?: pulumi.Input<string>;
    /**
     * Tags
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
