import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::SageMaker::MonitoringSchedule
 */
export declare function getMonitoringSchedule(args: GetMonitoringScheduleArgs, opts?: pulumi.InvokeOptions): Promise<GetMonitoringScheduleResult>;
export interface GetMonitoringScheduleArgs {
    /**
     * The Amazon Resource Name (ARN) of the monitoring schedule.
     */
    monitoringScheduleArn: string;
}
export interface GetMonitoringScheduleResult {
    /**
     * The time at which the schedule was created.
     */
    readonly creationTime?: string;
    /**
     * The name of the endpoint using the monitoring schedule.
     */
    readonly endpointName?: string;
    /**
     * Contains the reason a monitoring job failed, if it failed.
     */
    readonly failureReason?: string;
    /**
     * A timestamp that indicates the last time the monitoring job was modified.
     */
    readonly lastModifiedTime?: string;
    /**
     * Describes metadata on the last execution to run, if there was one.
     */
    readonly lastMonitoringExecutionSummary?: outputs.sagemaker.MonitoringScheduleMonitoringExecutionSummary;
    /**
     * The Amazon Resource Name (ARN) of the monitoring schedule.
     */
    readonly monitoringScheduleArn?: string;
    /**
     * The configuration object that specifies the monitoring schedule and defines the monitoring job.
     */
    readonly monitoringScheduleConfig?: outputs.sagemaker.MonitoringScheduleConfig;
    /**
     * The status of a schedule job.
     */
    readonly monitoringScheduleStatus?: enums.sagemaker.MonitoringScheduleStatus;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::SageMaker::MonitoringSchedule
 */
export declare function getMonitoringScheduleOutput(args: GetMonitoringScheduleOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMonitoringScheduleResult>;
export interface GetMonitoringScheduleOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the monitoring schedule.
     */
    monitoringScheduleArn: pulumi.Input<string>;
}
