import * as pulumi from "@pulumi/pulumi";
/**
 * The AWS::SecurityHub::Hub resource represents the implementation of the AWS Security Hub service in your account. One hub resource is created for each Region in which you enable Security Hub.
 */
export declare function getHub(args: GetHubArgs, opts?: pulumi.InvokeOptions): Promise<GetHubResult>;
export interface GetHubArgs {
    /**
     * An ARN is automatically created for the customer.
     */
    arn: string;
}
export interface GetHubResult {
    /**
     * An ARN is automatically created for the customer.
     */
    readonly arn?: string;
    /**
     * Whether to automatically enable new controls when they are added to standards that are enabled
     */
    readonly autoEnableControls?: boolean;
    /**
     * This field, used when enabling Security Hub, specifies whether the calling account has consolidated control findings turned on. If the value for this field is set to SECURITY_CONTROL, Security Hub generates a single finding for a control check even when the check applies to multiple enabled standards.  If the value for this field is set to STANDARD_CONTROL, Security Hub generates separate findings for a control check when the check applies to multiple enabled standards.
     */
    readonly controlFindingGenerator?: string;
    /**
     * The date and time when Security Hub was enabled in the account.
     */
    readonly subscribedAt?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * The AWS::SecurityHub::Hub resource represents the implementation of the AWS Security Hub service in your account. One hub resource is created for each Region in which you enable Security Hub.
 */
export declare function getHubOutput(args: GetHubOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetHubResult>;
export interface GetHubOutputArgs {
    /**
     * An ARN is automatically created for the customer.
     */
    arn: pulumi.Input<string>;
}
