import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::SES::MailManagerRuleSet Resource Type
 */
export declare class MailManagerRuleSet extends pulumi.CustomResource {
    /**
     * Get an existing MailManagerRuleSet resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): MailManagerRuleSet;
    /**
     * Returns true if the given object is an instance of MailManagerRuleSet.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MailManagerRuleSet;
    /**
     * The Amazon Resource Name (ARN) of the rule set resource.
     */
    readonly ruleSetArn: pulumi.Output<string>;
    /**
     * The identifier of the rule set.
     */
    readonly ruleSetId: pulumi.Output<string>;
    /**
     * A user-friendly name for the rule set.
     */
    readonly ruleSetName: pulumi.Output<string | undefined>;
    /**
     * Conditional rules that are evaluated for determining actions on email.
     */
    readonly rules: pulumi.Output<outputs.ses.MailManagerRuleSetRule[]>;
    /**
     * The tags used to organize, track, or control access for the resource. For example, { "tags": {"key1":"value1", "key2":"value2"} }.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a MailManagerRuleSet resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MailManagerRuleSetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a MailManagerRuleSet resource.
 */
export interface MailManagerRuleSetArgs {
    /**
     * A user-friendly name for the rule set.
     */
    ruleSetName?: pulumi.Input<string>;
    /**
     * Conditional rules that are evaluated for determining actions on email.
     */
    rules: pulumi.Input<pulumi.Input<inputs.ses.MailManagerRuleSetRuleArgs>[]>;
    /**
     * The tags used to organize, track, or control access for the resource. For example, { "tags": {"key1":"value1", "key2":"value2"} }.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
