import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Associates a VPC with a service network.
 */
export declare class ServiceNetworkVpcAssociation extends pulumi.CustomResource {
    /**
     * Get an existing ServiceNetworkVpcAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ServiceNetworkVpcAssociation;
    /**
     * Returns true if the given object is an instance of ServiceNetworkVpcAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ServiceNetworkVpcAssociation;
    /**
     * The Amazon Resource Name (ARN) of the association between the service network and the VPC.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ID of the specified association between the service network and the VPC.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The date and time that the association was created, specified in ISO-8601 format.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The IDs of the security groups. Security groups aren't added by default. You can add a security group to apply network level controls to control which resources in a VPC are allowed to access the service network and its services. For more information, see [Control traffic to resources using security groups](https://docs.aws.amazon.com//vpc/latest/userguide/VPC_SecurityGroups.html) in the *Amazon VPC User Guide* .
     */
    readonly securityGroupIds: pulumi.Output<string[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the service network.
     */
    readonly serviceNetworkArn: pulumi.Output<string>;
    /**
     * The ID of the service network.
     */
    readonly serviceNetworkId: pulumi.Output<string>;
    /**
     * The ID or ARN of the service network. You must use an ARN if the resources are in different accounts.
     */
    readonly serviceNetworkIdentifier: pulumi.Output<string | undefined>;
    /**
     * The name of the service network.
     */
    readonly serviceNetworkName: pulumi.Output<string>;
    /**
     * The status of the association.
     */
    readonly status: pulumi.Output<enums.vpclattice.ServiceNetworkVpcAssociationStatus>;
    /**
     * The tags for the association.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The ID of the VPC.
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * The ID of the VPC.
     */
    readonly vpcIdentifier: pulumi.Output<string | undefined>;
    /**
     * Create a ServiceNetworkVpcAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ServiceNetworkVpcAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ServiceNetworkVpcAssociation resource.
 */
export interface ServiceNetworkVpcAssociationArgs {
    /**
     * The IDs of the security groups. Security groups aren't added by default. You can add a security group to apply network level controls to control which resources in a VPC are allowed to access the service network and its services. For more information, see [Control traffic to resources using security groups](https://docs.aws.amazon.com//vpc/latest/userguide/VPC_SecurityGroups.html) in the *Amazon VPC User Guide* .
     */
    securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The ID or ARN of the service network. You must use an ARN if the resources are in different accounts.
     */
    serviceNetworkIdentifier?: pulumi.Input<string>;
    /**
     * The tags for the association.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The ID of the VPC.
     */
    vpcIdentifier?: pulumi.Input<string>;
}
