import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource type definition for AWS::WorkSpacesThinClient::Environment.
 */
export declare class Environment extends pulumi.CustomResource {
    /**
     * Get an existing Environment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Environment;
    /**
     * Returns true if the given object is an instance of Environment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Environment;
    /**
     * Activation code for devices associated with environment.
     */
    readonly activationCode: pulumi.Output<string>;
    /**
     * The environment ARN.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Unique identifier of the environment.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The timestamp in unix epoch format when environment was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The ID of the software set to apply.
     */
    readonly desiredSoftwareSetId: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the desktop to stream from Amazon WorkSpaces, WorkSpaces Web, or AppStream 2.0.
     */
    readonly desktopArn: pulumi.Output<string>;
    /**
     * The URL for the identity provider login (only for environments that use AppStream 2.0).
     */
    readonly desktopEndpoint: pulumi.Output<string | undefined>;
    /**
     * The type of VDI.
     */
    readonly desktopType: pulumi.Output<enums.workspacesthinclient.EnvironmentDesktopType>;
    /**
     * An array of key-value pairs to apply to the newly created devices for this environment.
     */
    readonly deviceCreationTags: pulumi.Output<outputs.workspacesthinclient.EnvironmentTag[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the AWS Key Management Service key used to encrypt the environment.
     */
    readonly kmsKeyArn: pulumi.Output<string | undefined>;
    /**
     * A specification for a time window to apply software updates.
     */
    readonly maintenanceWindow: pulumi.Output<outputs.workspacesthinclient.EnvironmentMaintenanceWindow | undefined>;
    /**
     * The name of the environment.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * The ID of the software set that is pending to be installed.
     */
    readonly pendingSoftwareSetId: pulumi.Output<string>;
    /**
     * The version of the software set that is pending to be installed.
     */
    readonly pendingSoftwareSetVersion: pulumi.Output<string>;
    /**
     * Number of devices registered to the environment.
     */
    readonly registeredDevicesCount: pulumi.Output<number>;
    /**
     * Describes if the software currently installed on all devices in the environment is a supported version.
     */
    readonly softwareSetComplianceStatus: pulumi.Output<enums.workspacesthinclient.EnvironmentSoftwareSetComplianceStatus>;
    /**
     * An option to define which software updates to apply.
     */
    readonly softwareSetUpdateMode: pulumi.Output<enums.workspacesthinclient.EnvironmentSoftwareSetUpdateMode | undefined>;
    /**
     * An option to define if software updates should be applied within a maintenance window.
     */
    readonly softwareSetUpdateSchedule: pulumi.Output<enums.workspacesthinclient.EnvironmentSoftwareSetUpdateSchedule | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The timestamp in unix epoch format when environment was last updated.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * Create a Environment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EnvironmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Environment resource.
 */
export interface EnvironmentArgs {
    /**
     * The ID of the software set to apply.
     */
    desiredSoftwareSetId?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the desktop to stream from Amazon WorkSpaces, WorkSpaces Web, or AppStream 2.0.
     */
    desktopArn: pulumi.Input<string>;
    /**
     * The URL for the identity provider login (only for environments that use AppStream 2.0).
     */
    desktopEndpoint?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to the newly created devices for this environment.
     */
    deviceCreationTags?: pulumi.Input<pulumi.Input<inputs.workspacesthinclient.EnvironmentTagArgs>[]>;
    /**
     * The Amazon Resource Name (ARN) of the AWS Key Management Service key used to encrypt the environment.
     */
    kmsKeyArn?: pulumi.Input<string>;
    /**
     * A specification for a time window to apply software updates.
     */
    maintenanceWindow?: pulumi.Input<inputs.workspacesthinclient.EnvironmentMaintenanceWindowArgs>;
    /**
     * The name of the environment.
     */
    name?: pulumi.Input<string>;
    /**
     * An option to define which software updates to apply.
     */
    softwareSetUpdateMode?: pulumi.Input<enums.workspacesthinclient.EnvironmentSoftwareSetUpdateMode>;
    /**
     * An option to define if software updates should be applied within a maintenance window.
     */
    softwareSetUpdateSchedule?: pulumi.Input<enums.workspacesthinclient.EnvironmentSoftwareSetUpdateSchedule>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
