import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::WorkSpacesWeb::DataProtectionSettings Resource Type
 */
export declare class DataProtectionSettings extends pulumi.CustomResource {
    /**
     * Get an existing DataProtectionSettings resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DataProtectionSettings;
    /**
     * Returns true if the given object is an instance of DataProtectionSettings.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DataProtectionSettings;
    /**
     * The additional encryption context of the data protection settings.
     */
    readonly additionalEncryptionContext: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * A list of web portal ARNs that this data protection settings resource is associated with.
     */
    readonly associatedPortalArns: pulumi.Output<string[]>;
    /**
     * The creation date timestamp of the data protection settings.
     */
    readonly creationDate: pulumi.Output<string>;
    /**
     * The customer managed key used to encrypt sensitive information in the data protection settings.
     */
    readonly customerManagedKey: pulumi.Output<string | undefined>;
    /**
     * The ARN of the data protection settings resource.
     */
    readonly dataProtectionSettingsArn: pulumi.Output<string>;
    /**
     * The description of the data protection settings.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The display name of the data protection settings.
     */
    readonly displayName: pulumi.Output<string | undefined>;
    /**
     * The inline redaction configuration for the data protection settings.
     */
    readonly inlineRedactionConfiguration: pulumi.Output<outputs.workspacesweb.DataProtectionSettingsInlineRedactionConfiguration | undefined>;
    /**
     * The tags of the data protection settings.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a DataProtectionSettings resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: DataProtectionSettingsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DataProtectionSettings resource.
 */
export interface DataProtectionSettingsArgs {
    /**
     * The additional encryption context of the data protection settings.
     */
    additionalEncryptionContext?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The customer managed key used to encrypt sensitive information in the data protection settings.
     */
    customerManagedKey?: pulumi.Input<string>;
    /**
     * The description of the data protection settings.
     */
    description?: pulumi.Input<string>;
    /**
     * The display name of the data protection settings.
     */
    displayName?: pulumi.Input<string>;
    /**
     * The inline redaction configuration for the data protection settings.
     */
    inlineRedactionConfiguration?: pulumi.Input<inputs.workspacesweb.DataProtectionSettingsInlineRedactionConfigurationArgs>;
    /**
     * The tags of the data protection settings.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
